@@ -11,24 +11,25 @@ describe 'aodh::logging' do
     {
       :logging_context_format_string => '%(asctime)s.%(msecs)03d %(process)d %(levelname)s %(name)s [%(request_id)s %(user_identity)s] %(instance)s%(message)s',
       :logging_default_format_string => '%(asctime)s.%(msecs)03d %(process)d %(levelname)s %(name)s [-] %(instance)s%(message)s',
-      :logging_debug_format_suffix => '%(funcName)s %(pathname)s:%(lineno)d',
-      :logging_exception_prefix => '%(asctime)s.%(msecs)03d %(process)d TRACE %(name)s %(instance)s',
-      :log_config_append => '/etc/aodh/logging.conf',
-      :publish_errors => true,
-      :default_log_levels => {
+      :logging_debug_format_suffix   => '%(funcName)s %(pathname)s:%(lineno)d',
+      :logging_exception_prefix      => '%(asctime)s.%(msecs)03d %(process)d TRACE %(name)s %(instance)s',
+      :log_config_append             => '/etc/aodh/logging.conf',
+      :publish_errors                => true,
+      :default_log_levels            => {
         'amqp' => 'WARN', 'amqplib' => 'WARN', 'boto' => 'WARN',
         'sqlalchemy' => 'WARN', 'suds' => 'INFO', 'iso8601' => 'WARN',
         'requests.packages.urllib3.connectionpool' => 'WARN' },
-     :fatal_deprecations => true,
-     :instance_format => '[instance: %(uuid)s] ',
-     :instance_uuid_format => '[instance: %(uuid)s] ',
-     :log_date_format => '%Y-%m-%d %H:%M:%S',
-     :use_syslog => true,
-     :use_json => true,
-     :use_stderr => false,
-     :log_facility => 'LOG_FOO',
-     :log_dir => '/var/log',
-     :debug => true,
+     :fatal_deprecations             => true,
+     :instance_format                => '[instance: %(uuid)s] ',
+     :instance_uuid_format           => '[instance: %(uuid)s] ',
+     :log_date_format                => '%Y-%m-%d %H:%M:%S',
+     :use_syslog                     => true,
+     :use_journal                    => true,
+     :use_json                       => true,
+     :use_stderr                     => false,
+     :log_facility                   => 'LOG_FOO',
+     :log_dir                        => '/var/log',
+     :debug                          => true,
     }
   end
 
@@ -59,6 +60,7 @@ describe 'aodh::logging' do
       is_expected.to contain_oslo__log('aodh_config').with(
         :use_syslog          => '<SERVICE DEFAULT>',
         :use_json            => '<SERVICE DEFAULT>',
+        :use_journal         => '<SERVICE DEFAULT>',
         :use_stderr          => '<SERVICE DEFAULT>',
         :syslog_log_facility => '<SERVICE DEFAULT>',
         :log_dir             => '/var/log/aodh',
@@ -72,6 +74,7 @@ describe 'aodh::logging' do
       is_expected.to contain_oslo__log('aodh_config').with(
         :use_syslog          => true,
         :use_json            => true,
+        :use_journal         => true,
         :use_stderr          => false,
         :syslog_log_facility => 'LOG_FOO',
         :log_dir             => '/var/log',
